@@ -34,13 +34,12 @@ setMethodS3("byName", "AromaUnitTotalCnBinarySet", function(static, name, tags=N
   })
 
   suppressWarnings({
-    fromFiles(static, path=path, ..., pattern=".*,total[.]asb$");
+    byPath(static, path=path, ..., pattern=".*,total[.]asb$");
   })
 }, static=TRUE) 
 
 
 
-
 ############################################################################
 # HISTORY:
 # 2009-08-31
